# Building Documentation

A basic python environment with packages listed in `./requirements.txt` is
required to build the docs, see ``environment.yml``.

To make HTML documentation:

```bash
make html
```

Outputs to `build/html/index.html`
